@@ -110,7 +110,13 @@ static __attribute__ ((noreturn)) void *gxine_lirc_run (void *data)
 
       if (!first)
       {
+	pthread_cond_signal (&lirc_init_cond);
+	pthread_mutex_unlock (&lirc_init_mutex);
+	pthread_cleanup_push (gxine_lirc_cleanup, NULL);
         sleep (1);
+	pthread_testcancel();
+	pthread_cleanup_pop (0);
+	pthread_mutex_lock (&lirc_init_mutex);
         continue;
       }
 
