@@ -556,7 +556,7 @@ options:\n\
   -C, --configure KEY=VALUE\n\
                         alter a configuration item\n\
 \n"), VERSION, VENDOR_PKG_VERSION CSET_ID, argv[0]);
-    list_plugins (_("Available video drivers:"), xine_list_video_output_plugins);
+    list_plugins (_("Available video drivers:"), gxine_list_video_output_plugins);
     list_plugins (_("Available audio drivers:"), xine_list_audio_output_plugins);
   }
   else if (optstate & 4)
@@ -686,8 +686,7 @@ to the extent permitted by law.\n"),
   
     do
     {
-      if (entry.type == XINE_CONFIG_TYPE_STRING &&
-          (!xine_check_version (1, 1, 4) || entry.num_value) &&
+      if (entry.type == XINE_CONFIG_TYPE_STRING && entry.num_value &&
           !strncmp (entry.str_value, oldconfig, oldlen) &&
           (entry.str_value[oldlen] == '/' || entry.str_value[oldlen] == 0))
       {
