@@ -784,7 +784,7 @@ void create_menus (GtkWidget *window)
   GSList *proxy = gtk_action_get_proxies (get_action ("SubsMenu"));
   while (proxy)
   {
-    g_signal_connect (proxy->data, "event", subs_menu_cb, action);
+    g_signal_connect (proxy->data, "event", (GCallback) subs_menu_cb, action);
     proxy = g_slist_next (proxy);
   }
 }
